@@ -13,20 +13,19 @@ const useStyles = createUseStyles({
     content: {
         height: '100%',
         display: 'flex',
+        overflow: 'auto',
         flexDirection: 'column'
     },
     scrollable: {
         flex: 1,
-        overflow: 'auto'
+        paddingTop: '8px'
     },
     container: {
-        padding: '16px'
+        padding: '8px 16px 8px 16px'
     },
     buttonContainer: {
-        extend: 'container',
-        borderTop: '1px solid var(--jp-border-color2)'
+        extend: 'container'
     },
-    label: {},
     instanceName: {
         fontSize: '16pt'
     },
@@ -36,6 +35,20 @@ const useStyles = createUseStyles({
     formItem: {
         marginBottom: '16px'
     },
+    label: {
+        margin: '4px 0 4px 0'
+    },
+    textFieldContainer: {
+        margin: '8px 0 8px 0'
+    },
+    subtitle: {
+        color: 'var(--jp-ui-font-color2)',
+        fontSize: '9pt'
+    },
+    warning: {
+        extend: 'subtitle',
+        margin: '8px 8px 16px 8px'
+    },
     icon: {
         fontSize: '10pt',
         verticalAlign: 'middle'
@@ -47,12 +60,28 @@ const useStyles = createUseStyles({
     hidden: {
         display: 'none'
     },
+    action: {
+        cursor: 'pointer',
+        color: 'var(--jp-rucio-primary-blue-color)',
+        fontSize: '9pt'
+    },
     buttonSavedAcknowledgement: {
         background: '#689f38',
         color: '#ffffff',
         '&:hover': {
             background: '#689f38'
         }
+    },
+    buttonPurgedAcknowledgement: {
+        extend: 'purgeButton',
+        background: 'var(--jp-error-color1)',
+        color: '#ffffff',
+        '&:hover': {
+            background: 'var(--jp-error-color1)'
+        }
+    },
+    purgeButton: {
+        marginTop: '16px'
     }
 });
 const _Settings = props => {
@@ -70,6 +99,9 @@ const _Settings = props => {
     const [credentialsLoading, setCredentialsLoading] = useState(true);
     const [loading, setLoading] = useState(false);
     const [showSaved, setShowSaved] = useState(false);
+    const [showAdvancedSettings, setShowAdvancedSettings] = useState(false);
+    const [purgingCache, setPurgingCache] = useState(false);
+    const [showCachePurged, setShowCachePurged] = useState(false);
     const instanceOptions = useMemo(() => instances === null || instances === void 0 ? void 0 : instances.map(i => ({ label: i.displayName, value: i.name })), [instances]);
     const setActiveInstance = (instanceName, authType) => {
         UIStore.update(s => {
@@ -126,6 +158,17 @@ const _Settings = props => {
                 .finally(() => setCredentialsLoading(false));
         }
     };
+    const purgeCache = () => {
+        setShowCachePurged(false);
+        setPurgingCache(true);
+        actions
+            .purgeCache()
+            .then(() => {
+            setShowCachePurged(true);
+            setTimeout(() => setShowCachePurged(false), 3000);
+        })
+            .finally(() => setPurgingCache(false));
+    };
     useEffect(reloadAuthConfig, [selectedInstance, selectedAuthType]);
     const settingsComplete = selectedInstance && selectedAuthType;
     const selectStyles = {
@@ -153,7 +196,21 @@ const _Settings = props => {
                     React.createElement(UserPassAuth, { loading: credentialsLoading, params: rucioUserpassAuthCredentials, onAuthParamsChange: v => setRucioUserpassAuthCredentials(v) })),
                 React.createElement("div", { className: selectedInstance && selectedAuthType === 'x509' ? '' : classes.hidden },
                     React.createElement(HorizontalHeading, { title: "X.509 User Certificate" }),
-                    React.createElement(X509Auth, { loading: credentialsLoading, params: rucioX509AuthCredentials, onAuthParamsChange: v => setRucioX509AuthCredentials(v) })))),
+                    React.createElement(X509Auth, { loading: credentialsLoading, params: rucioX509AuthCredentials, onAuthParamsChange: v => setRucioX509AuthCredentials(v) }))),
+            React.createElement("div", { className: showAdvancedSettings ? undefined : classes.hidden },
+                React.createElement(HorizontalHeading, { title: "Advanced Settings" }),
+                React.createElement("div", { className: classes.container },
+                    React.createElement("div", { className: classes.formItem },
+                        React.createElement("div", { className: classes.textFieldContainer },
+                            React.createElement("div", { className: classes.label }, "Purge cache"),
+                            React.createElement("div", { className: classes.subtitle }, "Remove all caches, including search results and DID paths."),
+                            React.createElement(Button, { block: true, onClick: purgeCache, disabled: purgingCache, outlineColor: "var(--jp-error-color1)", color: !purgingCache && showCachePurged ? '#FFFFFF' : 'var(--jp-error-color1)', className: !purgingCache && showCachePurged ? classes.buttonPurgedAcknowledgement : classes.purgeButton },
+                                !purgingCache && !showCachePurged && React.createElement(React.Fragment, null, "Purge Cache"),
+                                purgingCache && React.createElement(React.Fragment, null, "Purging..."),
+                                !purgingCache && showCachePurged && React.createElement(React.Fragment, null, "Purged!")))))),
+            React.createElement("div", { className: classes.container },
+                !showAdvancedSettings && (React.createElement("div", { className: classes.action, onClick: () => setShowAdvancedSettings(true) }, "Show Advanced Settings")),
+                showAdvancedSettings && (React.createElement("div", { className: classes.action, onClick: () => setShowAdvancedSettings(false) }, "Hide Advanced Settings")))),
         React.createElement("div", { className: classes.buttonContainer },
             React.createElement(Button, { block: true, onClick: saveSettings, disabled: !settingsComplete || loading, outlineColor: !loading && showSaved ? '#689f38' : undefined, color: !loading && showSaved ? '#FFFFFF' : undefined, className: !loading && showSaved ? classes.buttonSavedAcknowledgement : undefined },
                 !loading && !showSaved && React.createElement(React.Fragment, null, "Save Settings"),
