@@ -106,6 +106,12 @@ export class Actions {
     async listDirectory(path) {
         return requestAPI('file-browser?path=' + encodeURIComponent(path));
     }
+    async purgeCache() {
+        const init = {
+            method: 'POST'
+        };
+        return requestAPI('purge-cache', init);
+    }
 }
 export const actions = new Actions();
 //eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
