@@ -1,5 +1,5 @@
 import { ExtensionStore } from '../stores/ExtensionStore';
-import { METADATA_KEY } from '../const';
+import { METADATA_ATTACHMENTS_KEY } from '../const';
 export class ActiveNotebookListener {
     constructor(options) {
         this.options = options;
@@ -28,10 +28,10 @@ export class ActiveNotebookListener {
     }
     setJupyterNotebookFileRucioMetadata(attachments, state) {
         const { metadata } = state.activeNotebookPanel.model;
-        const current = metadata.get(METADATA_KEY);
+        const current = metadata.get(METADATA_ATTACHMENTS_KEY);
         const rucioDidAttachments = attachments;
         if (current !== rucioDidAttachments) {
-            metadata.set(METADATA_KEY, rucioDidAttachments);
+            metadata.set(METADATA_ATTACHMENTS_KEY, rucioDidAttachments);
         }
     }
     onCurrentTabChanged() {
@@ -44,7 +44,7 @@ export class ActiveNotebookListener {
         const nbWidget = notebookTracker.currentWidget;
         nbWidget.revealed.then(() => {
             this.setActiveNotebook(nbWidget);
-            const rucioDidAttachments = nbWidget.model.metadata.get(METADATA_KEY);
+            const rucioDidAttachments = nbWidget.model.metadata.get(METADATA_ATTACHMENTS_KEY);
             if (!rucioDidAttachments) {
                 this.setActiveNotebookAttachments([]);
                 return;
