@@ -22,3 +22,7 @@ def filter(iterable, filter):
             result.append(element)
         i += 1
     return result
+
+
+def remove_none_values(dictionary):
+    return {k: v for k, v in dictionary.items() if v is not None}
